#import <Cocoa/Cocoa.h>
#import <QTKit/QTKit.h>

@interface methods : NSObject
+ (NSString *)makeTimeString:(QTTime)theTime;
+ (NSDictionary *)moviePropertiesForView:(QTMovieView *)movieView;
+ (NSDictionary *)movieProperties:(QTMovie *)movie;
+ (id)loadMovie:(QTMovieView *)movieView withPath:(NSString *)moviePath;
+ (void)setPreservesAspectRatio:(QTMovieView *)movieView shouldPreserve:(BOOL)yn;
@end

@implementation methods

+ (NSString *)makeTimeString:(QTTime)theTime {
    long long seconds, minutes, hours;
    seconds = theTime.timeValue/theTime.timeScale;
    minutes = seconds/60;
    hours = minutes/60;
    seconds = seconds - (minutes * 60);
    minutes = minutes - (hours * 60);
	NSString *_seconds = [NSString stringWithFormat:@"%qi", seconds];
	NSString *_minutes = [NSString stringWithFormat:@"%qi", minutes];
	if ([_seconds length] < 2) _seconds = [NSString stringWithFormat:@"0%@", _seconds];
	if ([_minutes length] < 2) _minutes = [NSString stringWithFormat:@"0%@", _minutes];
    return [NSString stringWithFormat:@"%qi:%@:%@", hours, _minutes, _seconds];
}

+ (NSDictionary *)moviePropertiesForView:(QTMovieView *)movieView {
    return [self movieProperties:[movieView movie]];
}

+ (NSDictionary *)movieProperties:(QTMovie *)movie {
    NSMutableDictionary *returnData = [NSMutableDictionary dictionary];
    [returnData setObject:[movie attributeForKey:QTMovieDisplayNameAttribute] forKey:@"display_name"];
	
    NSString *attribute = [movie attributeForKey:QTMovieCopyrightAttribute];
    if (attribute) {
		[returnData setObject:attribute forKey:@"copyright_string"];
    } else {
		[returnData setObject:@"" forKey:@"copyright_string"];
    }
	
    [returnData setObject:[movie attributeForKey:QTMovieCreationTimeAttribute] forKey:@"creation_date"];
    [returnData setObject:[movie attributeForKey:QTMovieModificationTimeAttribute] forKey:@"modification_date"];
    
    [returnData setObject:[NSNumber numberWithBool:(int)[movie attributeForKey:QTMovieHasAudioAttribute]] forKey:@"has_audio"];
    [returnData setObject:[NSNumber numberWithBool:(int)[movie attributeForKey:QTMovieHasVideoAttribute]] forKey:@"has_video"];
	
    NSSize size = [[movie attributeForKey:QTMovieCurrentSizeAttribute] sizeValue];
    [returnData setObject:[NSNumber numberWithFloat:size.width] forKey:@"current_width"];
    [returnData setObject:[NSNumber numberWithFloat:size.height] forKey:@"current_height"];
	
    size = [[movie attributeForKey:QTMovieNaturalSizeAttribute] sizeValue];
    [returnData setObject:[NSNumber numberWithFloat:size.width] forKey:@"default_width"];
    [returnData setObject:[NSNumber numberWithFloat:size.height] forKey:@"default_height"];
	
    [returnData setObject:[self makeTimeString:[movie duration]] forKey:@"duration_string"];
    [returnData setObject:[self makeTimeString:[movie currentTime]] forKey:@"current_time_string"];
    
    return returnData;
}

+ (id)loadMovie:(QTMovieView *)movieView withPath:(NSString *)moviePath {
    if ([QTMovie canInitWithFile:moviePath]) {
		[[movieView movie] stop];
		[movieView setMovie:[[[QTMovie alloc] initWithFile:moviePath error:nil] autorelease]];
		[[movieView movie] play];
		return [NSNumber numberWithBool:TRUE];
    } else {
		return [NSNumber numberWithBool:FALSE];
    }
}

+ (void)setPreservesAspectRatio:(QTMovieView *)movieView shouldPreserve:(BOOL)yn {
    [movieView setPreservesAspectRatio:yn];
}

@end
